@@ -212,10 +212,10 @@ int ENVIRONMENT::loadFromFile_Text (FILE *file)
       result = fgets(line, MAX_CONFIG_LINE, file);
       if (! result)     // eof
         return FALSE;
-      if (! strncmp(line, (char *)"***", 3) )     // end of record
+      if (! strncmp(line, "***", 3) )     // end of record
         return FALSE;
     }
-  while ( strncmp(line, (char *)"*ENV*", 5) );     // read until we hit new record
+  while ( strncmp(line, "*ENV*", 5) );     // read until we hit new record
 
   while ( (result) && (!done) )
     {
@@ -225,7 +225,7 @@ int ENVIRONMENT::loadFromFile_Text (FILE *file)
       if (result)
         {
           // if we hit end of the record, stop
-          if (! strncmp(line, (char *)"***", 3) ) return TRUE;
+          if (! strncmp(line, "***", 3) ) return TRUE;
           // find equal sign
           line_length = strlen(line);
           // strip newline character
@@ -247,48 +247,48 @@ int ENVIRONMENT::loadFromFile_Text (FILE *file)
               strncpy(field, line, equal_position);
               strcpy(value, & (line[equal_position + 1]));
               // check for fields and values
-              if (! strcasecmp(field, (char *)"windstrength") )
+              if (! strcasecmp(field, "windstrength") )
                 sscanf(value, "%lf", &windstrength);
-              else if (! strcasecmp(field, (char *)"windvariation") )
+              else if (! strcasecmp(field, "windvariation") )
                 sscanf(value, "%lf", &windvariation);
-              else if (! strcasecmp(field, (char *)"viscosity") )
+              else if (! strcasecmp(field, "viscosity") )
                 sscanf(value, "%lf", &viscosity);
-              else if (! strcasecmp(field, (char *)"gravity") )
+              else if (! strcasecmp(field, "gravity") )
                 sscanf(value, "%lf", &gravity);
-              else if (! strcasecmp(field, (char *)"techlevel"))
+              else if (! strcasecmp(field, "techlevel"))
                 {
                   sscanf(value, "%lf", &weapontechLevel);
                   itemtechLevel = weapontechLevel;    // for backward compatibility
                 }
-              else if (! strcasecmp(field, (char *)"weapontechlevel") )
+              else if (! strcasecmp(field, "weapontechlevel") )
                 sscanf(value, "%lf", &weapontechLevel);
-              else if (! strcasecmp(field, (char *)"itemtechlevel") )
+              else if (! strcasecmp(field, "itemtechlevel") )
                 sscanf(value, "%lf", &itemtechLevel);
-              else if (! strcasecmp(field, (char *)"meteors"))
+              else if (! strcasecmp(field, "meteors"))
                 sscanf(value, "%lf", &meteors);
-              else if (! strcasecmp(field, (char *)"lightning") )
+              else if (! strcasecmp(field, "lightning") )
                 sscanf(value, "%lf", &lightning);
-              else if (! strcasecmp(field, (char *)"satellite") )
+              else if (! strcasecmp(field, "satellite") )
                 sscanf(value, "%lf", &satellite);
-              else if (! strcasecmp(field, (char *)"fog") )
+              else if (! strcasecmp(field, "fog") )
                 sscanf(value, "%lf", &fog);
-              else if (! strcasecmp(field, (char *)"landtype"))
+              else if (! strcasecmp(field, "landtype"))
                 sscanf(value, "%lf", &landType);
-              else if (! strcasecmp(field, (char *)"landslidetype"))
+              else if (! strcasecmp(field, "landslidetype"))
                 sscanf(value, "%lf", &landSlideType);
-              else if (! strcasecmp(field, (char *)"walltype"))
+              else if (! strcasecmp(field, "walltype"))
                 sscanf(value, "%lf", &wallType);
-              else if (! strcasecmp(field, (char *)"boxmode"))
+              else if (! strcasecmp(field, "boxmode"))
                 sscanf(value, "%lf", &dBoxedMode);
-              else if (! strcasecmp(field, (char *)"textfade"))
+              else if (! strcasecmp(field, "textfade"))
                 sscanf(value, "%lf", &dFadingText);
-              else if (! strcasecmp(field, (char *)"textshadow"))
+              else if (! strcasecmp(field, "textshadow"))
                 sscanf(value, "%lf", &dShadowedText);
-              else if (! strcasecmp(field, (char *)"landslidedelay"))
+              else if (! strcasecmp(field, "landslidedelay"))
                 sscanf(value, "%lf", &landSlideDelay);
-              else if (! strcasecmp(field, (char *)"fallingdirtballs") )
+              else if (! strcasecmp(field, "fallingdirtballs") )
                 sscanf(value, "%lf", &falling_dirt_balls);
-              else if (! strcasecmp(field, (char *)"custombackground") )
+              else if (! strcasecmp(field, "custombackground") )
                 sscanf(value, "%lf", &custom_background);
 
             }    // end of found field=value line
@@ -984,3 +984,4 @@ void ENVIRONMENT::Reset_Options()
   custom_background = 0.0;
 }
 
+
