@@ -12,60 +12,6 @@
 #include "main.h"
 #include "text.h"
 
-// This function reads the lines of text from
-// a file. It returns a pointer to a random line
-// of text. On error, a NULL is returned.
-/*
-char *Random_Line(char *filename)
-{
-  FILE *my_file;
-  char line[MAX_INSULT_LINE];
-  char *return_value;
-  char *result;
-  int line_count = 0;
-  int grab_line;
-
-  if (! filename) return NULL;
-  my_file = fopen(filename, "r");
-  if (! my_file) return NULL;
-
-  // count the lines inthe file
-  result = fgets(line, MAX_INSULT_LINE, my_file);
-  while (result)
-    {
-      line_count++;
-      result = fgets(line, MAX_INSULT_LINE, my_file);
-    }
-
-  if (! line_count) return NULL;
-
-  // pick a random value
-  fseek(my_file, 0, SEEK_SET);
-  grab_line = rand() % line_count;
-
-  // find the selected line
-  line_count = 0;
-  while (line_count < grab_line)
-    {
-      result = fgets(line, MAX_INSULT_LINE, my_file);
-      line_count++;
-    }
-  fclose(my_file);
-
-  // remove CR and LF
-  if ( strchr(line, '\n') )
-    strchr(line, '\n')[0] = '\0';
-  if ( strchr(line, '\r') )
-    strchr(line, '\r')[0] = '\0';
-  // return the line we read
-  return_value = (char *) calloc( strlen(line) + 1, sizeof(char) );
-  if (! return_value) return NULL;
-  strcpy(return_value, line);
-  return return_value;
-}
-*/
-
-
 /*
 This function saves the game in progress.
 All data is saved in a text file for flexiblity.
@@ -478,7 +424,7 @@ void scrollTextList (GLOBALDATA *global, ENVIRONMENT *env,
   int my_key, done = FALSE;
   int moving = TRUE;
 
-  draw_circlesBG (global, env->db, 0, 0, global->screenWidth, global->screenHeight);
+  draw_circlesBG (global, env->db, 0, 0, global->screenWidth, global->screenHeight, false);
   drawMenuBackground (global, env, BACKGROUND_BLANK, abs (tOffset), numItems);
   quickChange (global, env->db);
   set_clip_rect (env->db, global->halfWidth - 300 + 1, 100 + 1,
@@ -487,9 +433,11 @@ void scrollTextList (GLOBALDATA *global, ENVIRONMENT *env,
   flush_inputs ();
   if (! global->os_mouse) show_mouse (NULL);
 
+  // lines->Display_All(TRUE);
   do
     {
       drawMenuBackground (global, env, BACKGROUND_BLANK, abs (tOffset), numItems);
+
       renderTextLines (global, env, lines, scrollOffset,
                        fnt, spacing );
       blit (env->db, screen, global->halfWidth - 300, 100, global->halfWidth - 300, 100,
@@ -501,7 +449,7 @@ void scrollTextList (GLOBALDATA *global, ENVIRONMENT *env,
          scrollOffset--;
       }
 
-      if (scrollOffset < -(global->halfHeight - 100 + lines->total_lines * 20))
+      if (scrollOffset < -(global->halfHeight - 100 + lines->total_lines * 30))
         scrollOffset = global->halfHeight - 100;
       if (global->close_button_pressed)
         break;
@@ -560,11 +508,12 @@ int Load_Weapons_Text(GLOBALDATA *global)
   int data_stage = 0;         // name, descrption, data
   int item_count = 0, weapon_count = 0, natural_count = 0;
 
+  setlocale(LC_NUMERIC, "C");
   // get path name
   path_to_file = (char *) calloc( strlen(global->dataDir) + 64, sizeof(char) );
   if (! path_to_file)
     {
-      printf( (char *)"Memory error occured while loading weapons.\n");
+      printf( "Memory error occured while loading weapons.\n");
       return FALSE;
     }
 
@@ -587,7 +536,7 @@ int Load_Weapons_Text(GLOBALDATA *global)
   // free(path_to_file);
   if (! wfile)
     {
-      printf( (char *)"Unable to open weapons file. (%s)\n", path_to_file);
+      printf( "Unable to open weapons file. (%s)\n", path_to_file);
       free(path_to_file);
       return FALSE;
     }
@@ -1081,3 +1030,62 @@ void Clear_Weapons()
 
 }
 
+
+
+int Display_Tank_Bitmap(ENVIRONMENT *env, int xpos, int ypos, void *image_number)
+{
+    double *temp_number = (double *) image_number;
+    int my_number = (int) *temp_number;
+    int use_tank_bitmap, use_turret_bitmap;
+    BITMAP *dest = env->db;
+    GLOBALDATA *global = env->_global;
+
+    switch (my_number)
+    {
+         case CLASSIC_TANK:
+          use_tank_bitmap = 8;
+          use_turret_bitmap = 1;
+          break;
+        case BIGGREY_TANK:
+          use_tank_bitmap = 9;
+          use_turret_bitmap = 2;
+          break;
+        case T34_TANK:
+          use_tank_bitmap = 10;
+          use_turret_bitmap = 3;
+          break;
+        case HEAVY_TANK:
+          use_tank_bitmap = 11;
+          use_turret_bitmap = 4;
+          break;
+        case FUTURE_TANK:
+          use_tank_bitmap = 12;
+          use_turret_bitmap = 5;
+          break;
+        case UFO_TANK:
+          use_tank_bitmap = 13;
+          use_turret_bitmap = 6;
+          break;
+        case SPIDER_TANK:
+          use_tank_bitmap = 14;
+          use_turret_bitmap = 7;
+          break;
+        case BIGFOOT_TANK:
+          use_tank_bitmap = 15;
+          use_turret_bitmap = 8;
+          break;
+        default:
+          use_tank_bitmap = 0;
+          use_turret_bitmap = 0;
+          break;
+
+    }
+
+    draw_sprite(dest, global->tank[use_tank_bitmap], xpos, ypos);
+    draw_sprite(dest, global->tankgun[use_turret_bitmap], xpos, ypos - TANKHEIGHT + 5);
+    
+    return TRUE;
+
+
+}
+
