@@ -14,11 +14,6 @@
 #include "environment.h"
 #include "text.h"
 
-// this function reads the text from a file
-// and returns a random line from the file.
-// On error, NULL is returned.
-// char *Random_Line(char *filename);
-
 
 int Save_Game(GLOBALDATA *global, ENVIRONMENT *env);
 int Load_Game(GLOBALDATA *global, ENVIRONMENT *env); 
@@ -40,7 +35,7 @@ void renderTextLines (GLOBALDATA *global, ENVIRONMENT *env,
 void scrollTextList (GLOBALDATA *global, ENVIRONMENT *env,
                      TEXTBLOCK *lines);
 
-int draw_circlesBG (GLOBALDATA *global, BITMAP *dest, int x, int y, int width, int height);
+int draw_circlesBG (GLOBALDATA *global, BITMAP *dest, int x, int y, int width, int height, bool image);
 
 void drawMenuBackground (GLOBALDATA *global, ENVIRONMENT *env, int itemType, int tOffset, int numItems);
 
@@ -73,4 +68,8 @@ double colorDistance(int col1, int col2);
 // Should be called before re-loading weapon file.
 void Clear_Weapons();
 
+
+// Draw a tank bitmap on the screen at the given location'
+int Display_Tank_Bitmap(ENVIRONMENT *env, int xpos, int ypos, void *image_number);
+
 #endif
