@@ -50,12 +50,15 @@ GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdate
   frames_per_second = FRAMES_PER_SECOND;
   numPermanentPlayers = 10;
   violent_death = FALSE;
+/*
 #ifndef DOS
   cacheCirclesBG = 1;
 #endif
+
 #ifdef DOS
   cacheCirclesBG = 0;
 #endif
+*/
   ditherGradients = 1;
   detailedLandscape = 0;
   detailedSky = 0;
@@ -63,7 +66,8 @@ GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdate
   startmoney = 15000;
   turntype = TURN_RANDOM;
   skipComputerPlay = SKIP_HUMANS_DEAD;
-  dataDir = DATA_DIR;
+  // dataDir = DATA_DIR;
+  Find_Data_Dir();
   os_mouse = 1.0;
   full_screen = FULL_SCREEN_FALSE;
   interest = 1.25;
@@ -88,6 +92,7 @@ GLOBALDATA::GLOBALDATA ():dataDir(NULL),configDir(NULL),updates(NULL),lastUpdate
   env = NULL;
   war_quotes = instructions = ingame = NULL;
   gloat = revenge = retaliation = kamikaze = suicide = NULL;
+  client_message= NULL;
 
   updates = new BOX[MAXUPDATES];
   if (!updates)
@@ -195,6 +200,7 @@ int GLOBALDATA::saveToFile_Text( FILE *file)
 {
   if (! file) return FALSE;
 
+  setlocale(LC_NUMERIC, "C");
 
   screenWidth = (int) temp_screenWidth;
   screenHeight = (int) temp_screenHeight;
@@ -318,6 +324,7 @@ int GLOBALDATA::loadFromFile_Text (FILE *file)
   bool done = false;
   double sound_bookmark = 1.0;
 
+  setlocale(LC_NUMERIC, "C");
   if (! sound)
     sound_bookmark = sound;
 
@@ -893,18 +900,31 @@ int GLOBALDATA::Load_Fonts()
 // right after a language change.
 void GLOBALDATA::Change_Font()
 {
-    FONT *temp_font = font;
+    // FONT *temp_font = font;
 
-    if (language == LANGUAGE_RUSSIAN)
+    if ( (language == LANGUAGE_RUSSIAN) || (language == LANGUAGE_GERMAN) )
        font = unicode;
     else
        font = regular_font;
 
-    if (temp_font != font)     // font has changed
-    {
+    // if (temp_font != font)     // font has changed
+    // {
        Load_Weapons_Text(this);
        Load_Text_Files();
-    }
+    // }
+}
+
+
+
+void GLOBALDATA::Update_Player_Menu()
+{
+   int index;
+
+   for (index = 0; index < numPermanentPlayers; index++)
+   {
+       if (allPlayers[index])
+          allPlayers[index]->initMenuDesc();
+   }
 }
 
 
@@ -970,3 +990,68 @@ int GLOBALDATA::Load_Text_Files()
     return TRUE;
 }
 
+
+#ifdef NETWORK
+// This function sends a message to all connected game clients.
+// Returns TRUE on success or FALSE if the message could not be sent
+int GLOBALDATA::Send_To_Clients(char *message)
+{
+   int index;
+   int message_length;
+
+   if (! message) return FALSE;
+   message_length = strlen(message);
+   for (index = 0; index < numPlayers; index++)
+   {
+       if ( (players[index]) && (players[index]->type == NETWORK_CLIENT) )
+          write(players[index]->server_socket, message, message_length);
+   }     // done all players
+   return TRUE;
+}
+#endif
+
+
+
+// This function tries to figure out where the dataDir is. It
+// first checks the current working directory, ".". If the
+// proper files are not found, then we try the defined value of
+// DATA_DIR.
+// On success, TRUE is returned. If no usable directory is
+// found, then FALSE is returned.
+int GLOBALDATA::Find_Data_Dir()
+{
+     char *current_dir = NULL;
+     FILE *my_phile;
+
+     current_dir = (char *) calloc( strlen(DATA_DIR) + 32, sizeof(char));
+     if (! current_dir)
+        return FALSE;
+
+     // try current dir
+     strcpy(current_dir, "./unicode.dat");   // local dir
+     my_phile = fopen(current_dir, "r");
+     if (my_phile)
+     {
+         fclose(my_phile);
+         free(current_dir);
+         dataDir = ".";
+         return TRUE;
+     }
+
+    // try system dir
+    sprintf(current_dir, "%s/unicode.dat", DATA_DIR);
+    my_phile = fopen(current_dir, "r");
+    if (my_phile)
+    {
+        fclose(my_phile);
+        free(current_dir);
+        dataDir = DATA_DIR;
+        return TRUE;
+    }
+
+    dataDir = DATA_DIR;    // fall back
+    free(current_dir);
+    return FALSE;
+}
+
+
