@@ -118,8 +118,8 @@ class GLOBALDATA
     ENVIRONMENT *env;
 
     // bool            full_screen;
-    int		cacheCirclesBG ;	/* This is just a flag, so it need only be
-								an integer, not a double */
+    // int		cacheCirclesBG ;	// This is just a flag, so it need only be
+						// 		an integer, not a double 
     void Reset_Options();
 
     /* Logically, these three variables should be ints.  However, converting
@@ -179,6 +179,8 @@ class GLOBALDATA
     FONT *unicode, *regular_font;
     TEXTBLOCK *war_quotes, *instructions, *ingame;
     TEXTBLOCK *gloat, *revenge, *retaliation, *suicide, *kamikaze;
+    char *client_message;   // message sent from client to main menu
+
 
     GLOBALDATA ();
     void	initialise ();
@@ -201,10 +203,15 @@ class GLOBALDATA
     SAMPLE *Load_Background_Music();
     int Load_Fonts();
     void Change_Font();
+    void Update_Player_Menu();
     int Load_Text_Files();
+    #ifdef NETWORK
+    int Send_To_Clients(char *message);        // send a short message to all network clients
+    #endif
 #ifdef DEBUG_AIM_SHOW
     bool bASD;
 #endif
+    int Find_Data_Dir();   
   };
 
 #endif
