@@ -21,7 +21,7 @@
  * */
 
 #ifndef VERSION
-#define VERSION "4.1"
+#define VERSION "4.5"
 #endif
 
 #ifdef GENTOO
@@ -65,7 +65,15 @@
 #define LINUX_SLEEP usleep(10000)
 #define LINUX_REST usleep(40000)
 #define LINUX_DREAMLAND sleep(5)
-#else
+#endif
+
+#ifdef MACOSX
+#define LINUX_SLEEP usleep(10000)
+#define LINUX_REST usleep(40000)
+#define LINUX_DREAMLAND sleep(5)
+#endif
+
+#ifdef WIN32
 #include <windows.h>
 #include <winbase.h>
 #define LINUX_SLEEP Sleep(10)
@@ -82,6 +90,9 @@ using namespace std;
 #ifdef LINUX
 #define HOME_DIR "HOME"
 #endif
+#ifdef MACOSX
+#define HOME_DIR "HOME"
+#endif
 
 #ifndef	DATA_DIR
 #define DATA_DIR "."
@@ -157,6 +168,11 @@ using namespace std;
 #define CLASSIC_TANK 1     // really 8 in the .dat file
 #define BIGGREY_TANK 2
 #define T34_TANK 3
+#define HEAVY_TANK 4
+#define FUTURE_TANK 5
+#define UFO_TANK 6
+#define SPIDER_TANK 7
+#define BIGFOOT_TANK 8
 
 
 // background images
@@ -360,13 +376,13 @@ typedef struct
 
     BITMAP		*sky_gradient_strips[ALL_SKIES];
     BITMAP		*land_gradient_strips[ALL_LANDS];
-    BITMAP		*circle_gradient_strip;
+    // BITMAP		*circle_gradient_strip;
     BITMAP		*stuff_bar_gradient_strip;
     BITMAP		*topbar_gradient_strip;
     BITMAP		*explosion_gradient_strip;
     BITMAP		*stuff_bar[2];
     BITMAP		*stuff_icon_base;
-    BITMAP		*circlesBG;
+    // BITMAP		*circlesBG;
     BITMAP		*topbar;
     BITMAP		*explosions[EXPLOSIONFRAMES];
     BITMAP		*flameFront[EXPLOSIONFRAMES];
