@@ -35,6 +35,7 @@ enum playerType
   DEADLY_PLAYER,
   LAST_PLAYER_TYPE,
   PART_TIME_BOT,         // normally a human, but acting as a deadly computer
+  VERY_PART_TIME_BOT,    // just fires one shot
   NETWORK_CLIENT
 };
 //player weapon preference type
@@ -54,12 +55,17 @@ enum turnStages
   FIRE_WEAPON
 };
 
+#define TANK_TYPES 8
+
 #define	NUM_ROULETTE_SLOTS (THINGS * 100)
 #define	MAX_WEAP_PROBABILITY	10000
 #define BURIED_LEVEL 135
 
 #define NET_COMMAND_SIZE 64
-
+// if we do not get a command after this amount of seconds,
+// turn control over to the computer for a moment
+#define NET_DELAY 1000
+#define NET_DELAY_SHORT 500
 
 class TANK;
 class PLAYER
@@ -95,10 +101,10 @@ class PLAYER
     int	rangeFind (int &aAngle, int &aPower);
 
   public:
-    double	type, type_saved;
+    double	type, type_saved, previous_type;
     double preftype;
     char* preftypeText[ALWAYS_PREF + 1];
-    char *tank_type[4];
+    char *tank_type[8];
     char *teamText[3];
 
     PLAYER	*revenge;
@@ -139,7 +145,7 @@ class PLAYER
     #endif
 
     PLAYER (GLOBALDATA *global, ENVIRONMENT *env);
-    PLAYER (GLOBALDATA *global, ENVIRONMENT *env, ifstream &ifsFile, bool file); 
+    // PLAYER (GLOBALDATA *global, ENVIRONMENT *env, ifstream &ifsFile, bool file); 
     ~PLAYER	();
     void	setName (char *name);
     char	*getName ()
@@ -178,6 +184,7 @@ class PLAYER
     int     Select_Random_Weapon();
     int     Select_Random_Item();
     int    Reduce_Time_Clock();
+    int    Buy_Something(int item_index);     // purchases the selected item
 
     #ifdef NETWORK
     void Trim_Newline(char *line);   // sanitize input
