@@ -28,8 +28,37 @@
 #include "beam.h"
 #include "tank.h"
 
+
+/*
+The deconstructor should be split into two pieces. One function for
+destroying a tank and another strictly for cleaning up a tank's memory
+whether it was destoryed or not.
+-- Jesse
+*/
 TANK::~TANK ()
 {
+/*
+  #ifdef NETWORK
+  if (player)        // we should always have a player, but better safe than sorry
+  {
+      int player_index = 0;
+      bool found = false;
+      char buffer[64];
+      while ( (player_index < _global->numPlayers) && (!found) )
+      {
+          // get the player index
+          if ( ( _global->players[player_index]->tank ) && (_global->players[player_index]->tank == this) )
+              found = true;
+          else
+              player_index++;
+     }
+     if (found)        // we should have found a match and now we send it to all clients
+     {
+         sprintf(buffer, "REMOVETANK %d", player_index);
+         _global->Send_To_Clients(buffer);
+     }
+  }
+  #endif
   if (_global && player)
     {
       int random_item;
@@ -93,6 +122,8 @@ TANK::~TANK ()
             }
         }
     }
+   */
+
   if (player)
     {
       player->tank = NULL;
@@ -192,7 +223,9 @@ void TANK::newRound ()
       player->ni[sht]++;
   sh = 0;
   repulsion = 0;
-  shPhase = rand () % 360;
+  // shPhase = rand () % 360;
+  shPhase = 0;
+  delta_phase = 0.1;
   sht = 0;
   l = 100;
   repair_rate = 0;
@@ -225,6 +258,99 @@ void TANK::newRound ()
 
 }
 
+
+
+void TANK::Destroy()
+{
+  #ifdef NETWORK
+  if (player)    // we should always have a player, but better safe than sorry
+  {
+      int player_index = 0;
+      bool found = false;
+      char buffer[64];
+      while ( (player_index < _global->numPlayers) && (!found) )
+      {
+          // get the player index
+          if ( ( _global->players[player_index]->tank ) && (_global->players[player_index]->tank == this) )
+              found = true;
+          else
+              player_index++;
+     }
+     if (found)        // we should have found a match and now we send it to all clients
+     {
+         sprintf(buffer, "REMOVETANK %d", player_index);
+         _global->Send_To_Clients(buffer);
+     }
+  }
+  #endif
+
+   if (_global && player)
+    {
+      int random_item;
+      if (_global->violent_death)
+        {
+          random_item = rand() % VIOLENT_CHANCE;
+          if ( ( random_item > _global->violent_death ) && (random_item <= VIOLENT_DEATH_HEAVY) )
+            random_item = (int) _global->violent_death;
+
+          switch (random_item)
+            {
+            case VIOLENT_DEATH_LIGHT:
+              player->ni[ITEM_VENGEANCE] += 1;
+              break;
+            case VIOLENT_DEATH_MEDIUM:
+              player->ni[ITEM_DYING_WRATH] += 1;
+              break;
+            case VIOLENT_DEATH_HEAVY:
+              player->ni[ITEM_FATAL_FURY] += 1;
+              break;
+            }     //end of switch
+        }
+
+        if (player->ni[ITEM_FATAL_FURY] > 0)
+        {
+          int numLaunch = (int)item[ITEM_FATAL_FURY].vals[SELFD_NUMBER];
+          cw = (int)item[ITEM_FATAL_FURY].vals[SELFD_TYPE];
+          player->ni[ITEM_FATAL_FURY]--;
+          player->nm[cw] += numLaunch;
+          for (int count = numLaunch; count > 0; count--)
+            {
+              a = rand () % 180 + 90;
+              p = rand () % (MAX_POWER / 2);
+              activateCurrentSelection ();
+            }
+        }
+        else if (player->ni[ITEM_DYING_WRATH] > 0)
+        {
+          int numLaunch = (int)item[ITEM_DYING_WRATH].vals[SELFD_NUMBER];
+          cw = (int)item[ITEM_DYING_WRATH].vals[SELFD_TYPE];
+          player->ni[ITEM_DYING_WRATH]--;
+          player->nm[cw] += numLaunch;
+          for (int count = numLaunch; count > 0; count--)
+            {
+              a = rand () % 180 + 90;
+              p = rand () % (MAX_POWER / 2);
+              activateCurrentSelection ();
+            }
+        }
+        else if (player->ni[ITEM_VENGEANCE] > 0)
+        {
+          int numLaunch = (int)item[ITEM_VENGEANCE].vals[SELFD_NUMBER];
+          cw = (int)item[ITEM_VENGEANCE].vals[SELFD_TYPE];
+          player->ni[ITEM_VENGEANCE]--;
+          player->nm[cw] += numLaunch;
+          for (int count = numLaunch; count > 0; count--)
+            {
+              a = rand () % 180 + 90;
+              p = rand () % (MAX_POWER / 2);
+              activateCurrentSelection ();
+            }
+        }
+    }
+}
+
+
+
 void TANK::update ()
 {
   VIRTUAL_OBJECT::update ();
@@ -406,11 +532,16 @@ void TANK::applyDamage ()
 
 void TANK::framelyAccounting ()
 {
+  /*
   if (shPhase < 0)
     shPhase = rand () % 360;
   shPhase += (int)(item[sht].vals[SHIELD_ENERGY] / sh) + 10;
   while (shPhase >= 360)
     shPhase -= 360;
+  */
+  shPhase = shPhase + delta_phase;
+  if ( ( shPhase > 5) || (shPhase < -2) )
+     delta_phase = -delta_phase;
 }
 
 int TANK::applyPhysics (GLOBALDATA *global)
@@ -598,10 +729,10 @@ void TANK::printHealth (int offset)
 
   // display player name
   if (nameText)
-    {
+  {
       textpos -= 10;
       nameText->set_pos ((int)x, (int)y - TANKHEIGHT + textpos + offset);
-    }
+  }
 }
 
 void TANK::draw (BITMAP *dest, int healthOffset)
@@ -618,8 +749,8 @@ void TANK::draw (BITMAP *dest, int healthOffset)
 
   // get bitmap for tank
   if (player)
-    {
-      switch ( (int) this->player->tank_bitmap)
+  {
+      switch ( (int) player->tank_bitmap)
         {
         case CLASSIC_TANK:
           use_tank_bitmap = 8;
@@ -639,6 +770,36 @@ void TANK::draw (BITMAP *dest, int healthOffset)
           turret_y = y;
           turret_x = x;
           break;
+        case HEAVY_TANK:
+          use_tank_bitmap = 11;
+          use_turret_bitmap = 4;
+          turret_y = y;
+          turret_x = x;
+          break;
+        case FUTURE_TANK:
+          use_tank_bitmap = 12;
+          use_turret_bitmap = 5;
+          turret_y = y;
+          turret_x = x;
+          break;
+        case UFO_TANK:
+          use_tank_bitmap = 13;
+          use_turret_bitmap = 6;
+          turret_y = y;
+          turret_x = x;
+          break;
+        case SPIDER_TANK:
+          use_tank_bitmap = 14;
+          use_turret_bitmap = 7;
+          turret_y = y;
+          turret_x = x;
+          break;
+         case BIGFOOT_TANK:
+          use_tank_bitmap = 15;
+          use_turret_bitmap = 8;
+          turret_y = y;
+          turret_x = x;
+          break;
         default:
           use_tank_bitmap = 0;
           use_turret_bitmap = 0;
@@ -654,6 +815,12 @@ void TANK::draw (BITMAP *dest, int healthOffset)
             (int) (y + TANKHEIGHT),
             this->player->color);
   // draw_sprite (dest, (BITMAP *) _global->gfxData.T[use_tank_bitmap].dat, (int) x - TANKWIDTH, (int) y);
+
+/*
+  Drawing shields this way seems to cause a crash on multi-cpu
+  systems. Taking this out and creating new shield
+  drawing routine below. -- Jesse
+
   if (sh > 0)
     {
       int phaseValue = 1;
@@ -683,7 +850,31 @@ void TANK::draw (BITMAP *dest, int healthOffset)
         }
       drawing_mode(DRAW_MODE_SOLID, NULL, 0, 0);
       _env->current_drawing_mode = DRAW_MODE_SOLID;
-    }
+    }   // end of drawing shield
+*/
+
+  if (sh > 0)
+  {
+     int thickness = 2;
+     int counter;
+     int wobble = (int) shPhase;
+
+     if ( (sht == ITEM_LGT_SHIELD) || (sht == ITEM_LGT_REPULSOR_SHIELD) )
+       thickness = 1;
+     else if ( (sht == ITEM_HVY_REPULSOR_SHIELD) || (sht == ITEM_HVY_SHIELD) )
+       thickness = 3;
+
+     if (! shieldColor)        // client may not have set colour
+     {
+         shieldColor = makecol ((int)item[sht].vals[SHIELD_RED],
+                             (int)item[sht].vals[SHIELD_GREEN],
+                             (int)item[sht].vals[SHIELD_BLUE]);
+     }
+     for (counter = 0; counter < thickness; counter++)
+         circle(dest, (int) x, (int) y, 
+                TANKHEIGHT + counter + wobble, shieldColor);
+  }
+
   draw_sprite (dest, (BITMAP *) _global->tank[use_tank_bitmap], (int) x - TANKWIDTH, (int) y);
   turretAngle = (int) ((float) (90 - a) * ((float) 256 / (float) 360));
   rotate_sprite (dest, (BITMAP *) _global->tankgun[use_turret_bitmap],
@@ -1031,7 +1222,7 @@ void TANK::boost_up_shield ()
     }
   else
     {
-      shieldText->set_text ( (char *)"");
+      shieldText->set_text ( "");
     }
 }
 void TANK::reactivate_shield ()
