@@ -54,7 +54,7 @@ class TANK: public PHYSICAL_OBJECT
     int	timer;
     int	teleTimer;
     int	teleXDest, teleYDest;
-    double	shPhase;
+    double	shPhase, delta_phase;
     PLAYER	*creditTo;
     FLOATTEXT	*healthText, *shieldText;//, *damageText;
     FLOATTEXT       *nameText;
@@ -67,6 +67,7 @@ class TANK: public PHYSICAL_OBJECT
     ~TANK ();
     TANK (GLOBALDATA *global, ENVIRONMENT *env);
     void	initialise ();
+    void Destroy();
     int	get_heaviest_shield ();
     void	boost_up_shield ();
     void	reactivate_shield ();
